==> activity-center-api-0.12.97-sources.jar: cn/com/duiba/tuia/activity/center/api/dto/staticpage/VerifyResultPageQuery.java <==
package cn.com.duiba.tuia.activity.center.api.dto.staticpage;

import cn.com.duiba.tuia.activity.center.api.dto.req.ReqPageQuery;

import java.util.Date;

public class VerifyResultPageQuery extends ReqPageQuery {

    /**
     * 审核平台 1-爱奇艺
     */
    private Integer platformType;

    /**
     * 审核页面类型 1：活动，2：落地页
     */
    private Integer pageType;

    /**
     * 审核开始时间
     */
    private Date verifyStartDate;

    /**
     * 审核结束时间
     */
    private Date verifyEndDate;

    /**
     * 静态页面URL
     */
    private String tuiaUrl;

    /**
     * 审核状态 1：送审中，2-审核通过 3-审核拒绝
     */
    private Integer verifyStatus;

    public Integer getPlatformType() {
        return platformType;
    }

    public void setPlatformType(Integer platformType) {
        this.platformType = platformType;
    }

    public Integer getPageType() {
        return pageType;
    }

    public void setPageType(Integer pageType) {
        this.pageType = pageType;
    }

    public Date getVerifyStartDate() {
        return verifyStartDate;
    }

    public void setVerifyStartDate(Date verifyStartDate) {
        this.verifyStartDate = verifyStartDate;
    }

    public Date getVerifyEndDate() {
        return verifyEndDate;
    }

    public void setVerifyEndDate(Date verifyEndDate) {
        this.verifyEndDate = verifyEndDate;
    }

    public String getTuiaUrl() {
        return tuiaUrl;
    }

    public void setTuiaUrl(String tuiaUrl) {
        this.tuiaUrl = tuiaUrl;
    }

    public Integer getVerifyStatus() {
        return verifyStatus;
    }

    public void setVerifyStatus(Integer verifyStatus) {
        this.verifyStatus = verifyStatus;
    }

}

==> activity-center-api-0.13.26-sources.jar: cn/com/duiba/tuia/activity/center/api/dto/staticpage/VerifyResultPageQuery.java <==
package cn.com.duiba.tuia.activity.center.api.dto.staticpage;

import cn.com.duiba.tuia.activity.center.api.dto.req.ReqPageQuery;

import java.util.Date;
import java.util.List;

public class VerifyResultPageQuery extends ReqPageQuery {

    /**
     * 审核平台 1-爱奇艺
     */
    private Integer platformType;

    /**
     * 审核页面类型 1：活动，2：落地页
     */
    private Integer pageType;

    /**
     * 审核开始时间
     */
    private Date verifyStartDate;

    /**
     * 审核结束时间
     */
    private Date verifyEndDate;

    /**
     * 静态页面URL
     */
    private String tuiaUrl;

    /**
     * 审核状态 1：送审中，2-审核通过 3-审核拒绝
     */
    private Integer verifyStatus;

    /**
     * 静态页面URL LIST
     */
    private List<String> tuiaUrlList;

    public Integer getPlatformType() {
        return platformType;
    }

    public void setPlatformType(Integer platformType) {
        this.platformType = platformType;
    }

    public Integer getPageType() {
        return pageType;
    }

    public void setPageType(Integer pageType) {
        this.pageType = pageType;
    }

    public Date getVerifyStartDate() {
        return verifyStartDate;
    }

    public void setVerifyStartDate(Date verifyStartDate) {
        this.verifyStartDate = verifyStartDate;
    }

    public Date getVerifyEndDate() {
        return verifyEndDate;
    }

    public void setVerifyEndDate(Date verifyEndDate) {
        this.verifyEndDate = verifyEndDate;
    }

    public String getTuiaUrl() {
        return tuiaUrl;
    }

    public void setTuiaUrl(String tuiaUrl) {
        this.tuiaUrl = tuiaUrl;
    }

    public Integer getVerifyStatus() {
        return verifyStatus;
    }

    public void setVerifyStatus(Integer verifyStatus) {
        this.verifyStatus = verifyStatus;
    }

    public List<String> getTuiaUrlList() {
        return tuiaUrlList;
    }

    public void setTuiaUrlList(List<String> tuiaUrlList) {
        this.tuiaUrlList = tuiaUrlList;
    }
}
